@@ -130,10 +130,10 @@ extern void zoombox(xcWidget, caddr_t, caddr_t);
 extern void zoomin(int, int);
 extern void zoomout(int, int);
 extern void warppointer(int, int);
-extern void panbutton(u_int, int, int);
+extern void panbutton(u_int, int, int, float);
 extern void zoominrefresh(int, int);
 extern void zoomoutrefresh(int, int);
-extern void panrefresh(u_int, int, int);
+extern void panrefresh(u_int, int, int, float);
 extern void checkwarp(XPoint *);
 extern int checkcycle(short, short);
 extern void copyvirtual();
@@ -182,7 +182,10 @@ extern Boolean checkname(objectptr);
 extern char *checkpostscriptname(char *, int *, objectptr);
 extern objectptr finddot();
 extern void movepoints(genericptr *, short, short);
-extern void domakeobject(xcWidget, caddr_t);
+#ifndef TCL_WRAPPER
+extern void xlib_makeobject(xcWidget, caddr_t);
+#endif
+extern void domakeobject(int);
 extern void selectsave(xcWidget, caddr_t, caddr_t);
 extern void arceditpush(arcptr);
 extern void splineeditpush(splineptr);
@@ -752,11 +755,14 @@ extern void copypinlabel(labelptr);
 extern int checkschem(objectptr, char *);
 extern int checksym(objectptr, char *);
 extern void changeotherpins(labelptr, stringpart *);
-extern void swapschem(xcWidget, pointertype, caddr_t);
+extern void swapschem(int, int);
 extern void dobeforeswap(xcWidget, caddr_t, caddr_t);
 extern void schemdisassoc();
 extern void startschemassoc(xcWidget, pointertype, caddr_t);
 extern Boolean schemassoc(objectptr, objectptr);
+#ifndef TCL_WRAPPER
+extern void xlib_swapschem(xcWidget, pointertype, caddr_t);
+#endif
 
 /* from selection.c: */
 
