@@ -809,27 +809,39 @@ void changeotherpins(labelptr newlabel, stringpart *oldstring)
 }
 
 /*----------------------------------------------------------------------*/
-/* Swap object schematic and symbol pages.   				*/
-/*  mode = 0 disallows creation of a new schematic or symbol; i.e., if	*/
-/*  there is no corresponding schematic/symbol, nothing happens.	*/
+/* Xt wrapper for swapschem()						*/
 /*----------------------------------------------------------------------*/
 
-void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
+void xlib_swapschem(xcWidget w, pointertype mode, caddr_t calldata)
+{
+   swapschem((int)mode, -1);
+}
+
+/*----------------------------------------------------------------------*/
+/* Swap object schematic and symbol pages.   				*/
+/*  allow_create = 0 disallows creation of a new schematic or symbol;	*/
+/*  i.e., if there is no corresponding schematic/symbol, nothing	*/
+/*  happens.								*/
+/*----------------------------------------------------------------------*/
+
+void swapschem(int allow_create, int libnum)
 {
    objectptr savepage = topobject;
    labelptr  *pinlab;
    genericptr *plab;
    Boolean lflag;
    pushlistptr stacktop;
+   short loclibnum = libnum;
 
    if (areastruct.schemon == False) return;
+   if (libnum == -1) loclibnum = USERLIB - LIBRARY;
 
    if (eventmode == MOVE_MODE || eventmode == COPY_MODE)
       standard_element_delete(NORMAL);
 
-   /* Create symbol or schematic, if allowed by mode */
+   /* Create symbol or schematic, if allowed by allow_create */
 
-   if ((topobject->symschem == NULL) && (mode != 0)
+   if ((topobject->symschem == NULL) && (allow_create != 0)
 		&& (topobject->schemtype != SECONDARY)) {
       if (topobject->schemtype != PRIMARY) {
 	 int tpage;
@@ -850,15 +862,14 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
       }
       else {
 	 objectptr *newobject;
-	 short libnum = USERLIB - LIBRARY;
 
 	 /* create a new library object for the new symbol */
 
-	 xobjs.userlibs[libnum].library = (objectptr *)
-		realloc(xobjs.userlibs[libnum].library,
-		++xobjs.userlibs[libnum].number * sizeof(objectptr));
-	 newobject = xobjs.userlibs[libnum].library
-		+ xobjs.userlibs[libnum].number - 1;
+	 xobjs.userlibs[loclibnum].library = (objectptr *)
+		realloc(xobjs.userlibs[loclibnum].library,
+		++xobjs.userlibs[loclibnum].number * sizeof(objectptr));
+	 newobject = xobjs.userlibs[loclibnum].library
+		+ xobjs.userlibs[loclibnum].number - 1;
          *newobject = (objectptr) malloc(sizeof(object));
 	 initmem(*newobject);
 	 (*newobject)->schemtype = SYMBOL;
@@ -870,7 +881,7 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
 	 /* top instance to point to it.			    */
 
 	 push_stack(&areastruct.stack, areastruct.topinstance);
-	 areastruct.topinstance = addtoinstlist(libnum, *newobject, FALSE);
+	 areastruct.topinstance = addtoinstlist(loclibnum, *newobject, FALSE);
 
 	 /* Generate the default bounding box for a size-zero object */
 	 calcbbox(areastruct.topinstance);
@@ -926,7 +937,7 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
       calcbbox(areastruct.topinstance);
 
       /* Recreate the user library with the new symbol */
-      if (savepage->schemtype != SYMBOL) composelib(USERLIB);
+      if (savepage->schemtype != SYMBOL) composelib(loclibnum + LIBRARY);
    }
    else if (topobject->symschem != NULL) {
 
@@ -987,6 +998,8 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
    setsymschem();
 }
 
+#ifndef TCL_WRAPPER
+
 /*----------------------------------------------------------------------*/
 /* Wrapper for swapschem() when generating a new symbol.		*/
 /*----------------------------------------------------------------------*/
@@ -997,7 +1010,7 @@ void makesymbol(xcWidget w, caddr_t calldata)
 
    strcpy(topobject->name, _STR2);
    checkname(topobject);
-   swapschem(w, (pointertype)1, calldata);
+   swapschem(1, -1);
 }
 
 /*----------------------------------------------------------------------*/
@@ -1026,9 +1039,11 @@ void dobeforeswap(xcWidget w, caddr_t clientdata, caddr_t calldata)
       popupprompt(w, "Enter name for new object:", "\0", makesymbol, popdata, NULL);
    }
    else
-      swapschem(w, (pointertype)1, calldata);
+      swapschem(1, -1);
 }
 
+#endif /* !TCL_WRAPPER */
+
 /*------------------------------------------*/
 /* Disassociate a symbol from its schematic */
 /*------------------------------------------*/
