@@ -273,8 +273,8 @@ typedef struct {
 
 /*----------------------------------------------------------------------*/
 
-#define RADFAC 0.0174532925199   /* pi / 180 */
-#define INVRFAC 57.295779       /* 180 / pi */
+#define RADFAC 0.0174532925199  /* (pi / 180) */
+#define INVRFAC 57.295779 /* (180 / pi) */
 
 /*----------------------------------------------------------------------*/
 
@@ -1342,7 +1342,7 @@ typedef struct _undostack {
 typedef struct {
    short	number;
    objectptr	*library;
-   liblistptr	instlist;  /* List of instances */
+   liblistptr	instlist;	/* List of instances */
 } Library;
 
 /*----------------------------------------------------------------------*/
